Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

C |
| candleStick, $.jqplot.OHLCRenderer
| Change Log
| Changes
| clearRect, $.jqplot.shapeRenderer
| clickReset, $.jqplot.Cursor
| closeColor, $.jqplot.OHLCRenderer
| color $.jqplot.CanvasOverlay$.jqplot.Dragable$.jqplot.LineRenderer$.jqplot.MarkerRenderer$.jqplot.Trendline Series
| constrainOutsideZoom, $.jqplot.Cursor
| constrainSmoothing, $.jqplot.LineRenderer
| constrainTo, $.jqplot.Dragable
| constrainZoomTo, $.jqplot.Cursor
| copy, $.jqplot.ThemeEngine
| Copyright&License
| css, $.jqplot.BlockRenderer
| cursorLegendFormatString, $.jqplot.Cursor
D |
| DashedHorizontalLine
| DashedVerticalLine
| dashPattern DashedHorizontalLine DashedVerticalLine
| data, jqPlot
| dataLabelCenterOn, $.jqplot.PieRenderer
| dataLabelFormatString $.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.PieRenderer
| dataLabelNudge $.jqplot.DonutRenderer$.jqplot.PieRenderer
| dataLabelPositionFactor $.jqplot.DonutRenderer$.jqplot.PieRenderer
| dataLabels $.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.PieRenderer
| dataLabelThreshold $.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.PieRenderer
| dataRenderer, jqPlot
| dataRendererOptions, jqPlot
| dblClickReset, $.jqplot.Cursor
| defaultAxisStart, jqPlot
| depth, $.jqplot.shadowRenderer
| destroy, jqPlot
| diameter $.jqplot.DonutRenderer$.jqplot.MeterGaugeRenderer$.jqplot.PieRenderer
| disableIEFading
| disableStack, Series
| downBodyColor, $.jqplot.OHLCRenderer
| draw $.jqplot.shadowRenderer$.jqplot.shapeRenderer jqPlot
| drawBaseline Global$.jqplot.DateAxisRenderer$.jqplot.LinearAxisRenderer$.jqplot.LogAxisRenderer
| drawBorder, Grid
| drawGridlines, Grid
| drawMajorGridlines, Axis
| drawMajorTickMarks, Axis
| drawMinorGridlines, Axis
| drawMinorTickMarks, Axis
| drawSeries, jqPlot
E |
| edgeTolerance, $.jqplot.PointLabels
| enableFontSupport $.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer
| escapeHtml $.jqplot.BlockRenderer$.jqplot.BubbleRenderer Legend Title
| escapeHTML $.jqplot.AxisLabelRenderer$.jqplot.AxisTickRenderer$.jqplot.PointLabels
| eventListenerHooks, $.jqplot.$.jqplot

> this.candleStick = false

true to render chart as candleStick.
See Change Log

> this.clearRect = false

true to cear a rectangle.

> this.clickReset = false

Will reset plot zoom if single click on plot without drag.

> this.closeColor = null

color of the close price tick mark.
color of the line

> this.color

CSS color spec for the dragged point (and adjacent line segment or bar).
color of lines at top and bottom of bands [default: series color].

> this.color = '#666666'

color of marker.

> this.color = '#666666'

CSS color spec for the trend line.

> this.color

css color spec for the series

> this.constrainOutsideZoom = true

True to limit actual zoom area to edges of grid, even when zooming outside of plot area.

> this.renderer.constrainSmoothing = true

True to use a more accurate smoothing algorithm that will not overshoot any data points.

> this.constrainTo = 'none'

Constrain dragging motion to an axis or to none.

> this.constrainZoomTo = 'none'

‘none’, ‘x’ or ‘y’

> $.jqplot.ThemeEngine.prototype.copy = function ( | sourceName,
> | targetName,
> | obj | )

Create a copy of an existing theme in the themeEngine, adding it the themeEngine.
Copyright © 2009-2013 Chris Leonello jqPlot is currently available for use in all personal or commercial projects under both the MIT and GPL version 2.0 licenses.

> this.css = {padding:'2px', border:'1px solid #999', textAlign:'center'}

default css styles that will be applied to all data blocks.

> this.cursorLegendFormatString = $.jqplot.Cursor.cursorLegendFormatString

Format string used in the cursor legend.
A straight dashed horizontal line.
A straight dashed vertical line.

> dashPattern: [8,8] }

Array of line, space settings in pixels.

> dashPattern: [8,8] }

Array of line, space settings in pixels.

> this.data = []

user’s data.

> this.dataLabelCenterOn = true

True to center the data label at its position.

> this.dataLabelFormatString = null

Format string for data labels.

> this.dataLabelFormatString = null

Format string for data labels.

> this.dataLabelFormatString = null

Format string for data labels.

> this.dataLabelNudge = 0

Number of pixels to slide the label away from (+) or toward (-) the center of the pie.

> this.dataLabelNudge = 2

Number of pixels to slide the label away from (+) or toward (-) the center of the pie.

> this.dataLabelPositionFactor = 0.4

A Multiplier (0-1) of the pie radius which controls position of label on slice.

> this.dataLabelPositionFactor = 0.52

A Multiplier (0-1) of the pie radius which controls position of label on slice.

> this.dataLabels = 'percent'

Either ‘label’, ‘value’, ‘percent’ or an array of labels to place on the pie slices.

> this.dataLabels = 'percent'

Either ‘label’, ‘value’, ‘percent’ or an array of labels to place on the pie slices.

> this.dataLabels = 'percent'

Either ‘label’, ‘value’, ‘percent’ or an array of labels to place on the pie slices.

> this.dataLabelThreshold = 3

> this.dataLabelThreshold = 3

> this.dataLabelThreshold = 3

Threshhold in percentage (0-100) of pie area, below which no label will be displayed.

> this.dataRenderer

A callable which can be used to preprocess data passed into the plot.

> this.dataRendererOptions

Options that will be passed to the dataRenderer.

> this.dblClickReset = true

Will reset plot zoom if double click on plot without drag.

> this.defaultAxisStart = 1

1-D data series are internally converted into 2-D [x,y] data point arrays by jqPlot.

> this.depth = 3

how many times the shadow is stroked.

> this.destroy = function()

Releases all resources occupied by the plot

> this.diameter = null

Outer diameter of the donut, auto computed by default

> this.diameter = null

Outer diameter of the meterGauge, auto computed by default

> this.diameter = null

Outer diameter of the pie, auto computed by default

> this.disableIEFading = true

true to toggle series with a show/hide method only and not allow fading in/out.

> this.disableStack = false

true to not stack this series with other series in the plot.

> this.downBodyColor = null

Color of candlestick body on a “down” day.

> $.jqplot.ShadowRenderer.prototype.draw = function( | ctx,
> | points,
> | options | )

draws an transparent black (i.e.

> $.jqplot.ShapeRenderer.prototype.draw = function( | ctx,
> | points,
> | options | )

draws the shape.

> this.draw = function()

Draws all elements of the plot into the container.

> this.drawBaseline = true

True to draw the axis baseline.

> this.drawBaseline = true

True to draw the axis baseline.

> this.drawBaseline = true

True to draw the axis baseline.

> this.drawBaseline = true

True to draw the axis baseline.

> this.drawBorder = true

True to draw border around grid.

> this.drawGridlines = true

whether to draw the gridlines on the plot.

> this.drawMajorGridlines = true

True to draw gridlines for major axis ticks.

> this.drawMajorTickMarks = true

True to draw tick marks for major axis ticks.

> this.drawMinorGridlines = false

True to draw gridlines for minor ticks.

> this.drawMinorTickMarks = true

True to draw tick marks for minor ticks.

> this.drawSeries = function( | options,
> | idx | )

Redraws all or just one series on the plot.

> this.edgeTolerance = -5

Number of pixels that the label must be away from an axis boundary in order to be drawn.

> this.enableFontSupport = true

true to turn on native canvas font support in Mozilla 3.5+ and Safari 4+.

> this.enableFontSupport = true

true to turn on native canvas font support in Mozilla 3.5+ and Safari 4+.

> this.escapeHtml = false

true to escape html in the box label.

> this.escapeHtml = true

True to escape html in bubble label text.

> this.escapeHtml = false

True to escape special characters with their html entity equivalents in legend text.

> this.escapeHtml = false

True to escape special characters with their html entity equivalents in title text.

> this.escapeHTML = false

true to escape HTML entities in the label.

> this.escapeHTML = false

true to escape HTML entities in the label.

> this.escapeHTML = true

true to escape html entities in the labels.
called at the end of plot drawing, binds listeners to the event canvas which lays on top of the grid area.
Close